@@ -2,8 +2,4 @@ from lightning_fast import tools
 from lightning_fast import config_factory
 from lightning_fast import mongodb
 
-__all__ = [
-    "tools",
-    "config_factory",
-    "mongodb"
-]
+__all__ = ["tools", "config_factory", "mongodb"]
