@@ -8,7 +8,12 @@ import dask.dataframe as dd
 class DaskReader:
     @classmethod
     def read_raw_hive_data(
-        cls, file_path, sep="\t", dtype=None, partitions: int = 1, limit: Optional[int] = None
+        cls,
+        file_path,
+        sep="\t",
+        dtype=None,
+        partitions: int = 1,
+        limit: Optional[int] = None,
     ) -> Union[pd.DataFrame, dd.DataFrame]:
         if limit is None:
             df = dd.read_csv(file_path, sep=sep, dtype=dtype)
